package net.p0f.samples.rhpam_fuse_integration.processes;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.kie.api.KieServices;
import org.kie.api.runtime.KieContainer;
import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.rule.QueryResults;
import org.kie.api.runtime.rule.QueryResultsRow;

import net.p0f.samples.rhpam_fuse_integration.shared_dom.Award;
import net.p0f.samples.rhpam_fuse_integration.shared_dom.Customer;

public class ProcessWithListParams {
	public static void main(String... args) {
		KieContainer c = KieServices.Factory.get().getKieClasspathContainer();
		
		// Instantiate the ruleflowParams KB and its default session.
		KieSession s = c.getKieBase("ruleflowParams").newKieSession();

		Customer c1 = new Customer();
		c1.setName("John Doe");
		c1.setAge(27);
		c1.setLoyaltyLevel(Customer.GOLD);
		c1.setLoyaltyAge(10);
		c1.setMilesFlown(15000);

		Customer c2 = new Customer();
		c2.setName("Jane Doe");
		c2.setAge(35);
		c2.setLoyaltyLevel(Customer.PLATINUM);
		c2.setLoyaltyAge(10);
		
		Award a1 = new Award();
		Award a2 = new Award();

		// Wrapped types don't match the rule conditions.
		List<Customer> customers = new ArrayList<>();
		List<Award> awards = new ArrayList<>();
		
		customers.add(c1);
		customers.add(c2);
		
		awards.add(a1);
		awards.add(a2);

		Map<String, Object> p = new HashMap<>();
		p.put("customers", customers);
		p.put("awards", awards);

		s.startProcess("ruleflow.RulesWithListParams", p);
		s.fireAllRules();

		System.out.println("******** Examining Working Memory ********");

		// This time around, no Award facts are found in working memory...
		QueryResults qr = s.getQueryResults("Get Awards");
		for (QueryResultsRow qrr : qr) {
			Award award = (Award) qrr.get("award");
			System.out.println("Found award: " + award.toString());
		}

		System.out.println("******** Examining Process Parameters ********");

		// ...and neither do the Award objects get updated.
		System.out.println("Customers: " + customers);
		System.out.println("Awards: " + awards);

		// An ugly way of addressing this can be seen in ProcessWithListSubProcess
		s.dispose();

	}
}
