package net.p0f.samples.rhpam_fuse_integration.rules;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.kie.api.KieServices;
import org.kie.api.runtime.KieContainer;
import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.rule.QueryResults;
import org.kie.api.runtime.rule.QueryResultsRow;

import net.p0f.samples.rhpam_fuse_integration.shared_dom.Award;
import net.p0f.samples.rhpam_fuse_integration.shared_dom.Customer;

public class AgendaGroupsRightOrderLog {
	public static void main(String... args) {
		KieContainer c = KieServices.Factory.get().getKieClasspathContainer();
		
		// Instantiate the agenda KB and its default session.
		KieSession s = c.getKieBase("agendaRight").newKieSession();

		// Ensure agenda group activation in correct order (stack!)
		s.getAgenda().getAgendaGroup("awards").setFocus(); 		// third
		s.getAgenda().getAgendaGroup("promotion").setFocus(); 	// second
		s.getAgenda().getAgendaGroup("status").setFocus(); 		// first

		// Instantiate a logger and make it available to the rule engine.
		Logger foo = Logger.getLogger(AgendaGroupsRightOrderLog.class.getName());
		s.setGlobal("globalLogger", foo);

		// Create some customers (wrong loyalty levels!)
		Customer c1 = new Customer();
		c1.setName("John Doe");
		c1.setAge(27);
		c1.setMilesFlown(15000);
		c1.setLoyaltyLevel(Customer.GOLD);
		c1.setLoyaltyAge(5);

		Customer c2 = new Customer();
		c2.setName("Jane Doe");
		c2.setAge(35);
		c2.setMilesFlown(75000);
		// Deliberately not setting LL
		//c2.setLoyaltyLevel(Customer.PLATINUM);
		c2.setLoyaltyAge(10);

		s.insert(c1);
		s.insert(c2);

		s.fireAllRules();

		foo.log(Level.INFO, "******** Examining Working Memory ********");

		// This correctly reports a 10y/PLATINUM award for Jane Doe and nothing else.
		QueryResults qr = s.getQueryResults("Get Awards");
		for (QueryResultsRow qrr : qr) {
			Award award = (Award)qrr.get("award");
			foo.log(Level.INFO, "Found award : " + award.toString());
		}

		s.dispose();
	}
}
